:py:mod:`save_numpy_array_to_binary_com`
========================================

.. py:module:: save_numpy_array_to_binary_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = Save Array To Binary

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'Array In']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Input']

   

.. py:data:: ParameterNames
   :annotation: = ['File name', 'Timestamp', 'Expand Or Append', 'on Axis', 'dtype']

   

.. py:data:: ParameterTypes
   :annotation: = ['str', 'bool', 'bool', 'int', 'list']

   

.. py:data:: ParametersDefaultValues
   :annotation: = ['output.bin', True, True, 0, ['Same', 'int8', 'int16', 'int32', 'int64', 'uint8', 'uint16',...

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: save_numpy_array_com
   

   

